aboutsummaryrefslogtreecommitdiffstats
path: root/mail/mail-tools.h
diff options
context:
space:
mode:
Diffstat (limited to 'mail/mail-tools.h')
-rw-r--r--mail/mail-tools.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/mail/mail-tools.h b/mail/mail-tools.h
index 1178921bb7..da5c0af8ff 100644
--- a/mail/mail-tools.h
+++ b/mail/mail-tools.h
@@ -35,13 +35,13 @@ void mail_tool_camel_lock_down (void);
/* Get a CamelFolder from a root url and a foldername (uses the global session)*/
CamelFolder *
mail_tool_get_folder_from_urlname (const gchar *url, const gchar *name,
- gboolean create, CamelException *ex);
+ guint32 flags, CamelException *ex);
/* Get a useful name for a given CamelFolder (ie, not "mbox") */
const gchar *mail_tool_get_folder_name (CamelFolder *folder);
-/* Get the url for the local inbox */
-gchar *mail_tool_get_local_inbox_url (void);
+/* Get the url for the local inbox, index returns if the mailbox is indexed */
+gchar *mail_tool_get_local_inbox_url (int *index);
/* Get the filename for our movemail folder or storage */
gchar *mail_tool_get_local_movemail_path (void);